@@ -19,10 +19,6 @@ Initial M1 Solum CLI commands implemented (but not REST communications):
 * plan delete plan_name
 * plan list
 * plan show plan_id
-* assembly create assembly_name plan_name
-* assembly delete assembly_name
-* assembly list
-* assembly show assembly_id
 * languagepack create <NAME> <GIT_REPO_URL>
 * languagepack list
 * languagepack show <LP_ID>
@@ -49,24 +45,29 @@ import sys
 import httplib2
 import jsonschema
 from keystoneclient.v2_0 import client as keystoneclient
+import six
 
 import solumclient
+from solumclient.common.apiclient import exceptions
 from solumclient.common import cli_utils
 from solumclient.common import exc
 from solumclient.common import github
 from solumclient.common import yamlutils
-from solumclient.openstack.common.apiclient import exceptions
-from solumclient.v1 import app as cli_app
-from solumclient.v1 import assembly as cli_assem
-from solumclient.v1 import languagepack as cli_lp
-from solumclient.v1 import pipeline as cli_pipe
-from solumclient.v1 import plan as cli_plan
-from solumclient.v1 import workflow as cli_wf
+from solumclient import config
+
+
+def name_error_message(name_type):
+    return name_type + (" must be 1-100 characters long, only "
+                        "contain a-z,0-9,-,_ and start with "
+                        "an alphabet character.")
 
 
 def name_is_valid(string):
+    if not string or not string[0].isalpha():
+        return False
+
     try:
-        re.match(r'^([a-zA-Z0-9-_]{1,100})$', string).group(0)
+        re.match(r'^([a-z0-9-_]{1,100})$', string).group(0)
     except AttributeError:
         return False
     return True
@@ -74,23 +75,17 @@ def name_is_valid(string):
 
 def ValidName(string):
     if not name_is_valid(string):
-        raise AttributeError("Names must be 1-100 characters long and must "
-                             "only contain a-z,A-Z,0-9,-,_")
+        raise AttributeError(name_error_message("Names"))
     return string
 
 
 def lpname_is_valid(string):
-    try:
-        re.match(r'^([a-z0-9-_]{1,100})$', string).group(0)
-    except (TypeError, AttributeError):
-        return False
-    return True
+    return name_is_valid(string)
 
 
 def ValidLPName(string):
     if not lpname_is_valid(string):
-        raise AttributeError("LP names must be 1-100 characters long and "
-                             "must only contain a-z,0-9,-,_")
+        raise AttributeError(name_error_message("LP names"))
     return string
 
 
@@ -219,7 +214,7 @@ Available commands:
         self.parser._names['plan_uuid'] = 'plan'
         args = self.parser.parse_args()
         plan = self.client.plans.find(name_or_id=args.plan_uuid)
-        cli_plan.PlanManager(self.client).delete(plan_id=str(plan.uuid))
+        self.client.plans.delete(plan_id=str(plan.uuid))
 
     def show(self):
         """Show a plan's resource."""
@@ -240,89 +235,6 @@ Available commands:
         self._print_list(plans, fields)
 
 
-class AssemblyCommands(cli_utils.CommandsBase):
-    """Commands for working with assemblies.
-
-Available commands:
-
-    solum assembly list
-        Print an index of all available assemblies.
-
-    solum assembly show <NAME|UUID>
-        Print the details of an assembly.
-
-    solum assembly create <NAME|UUID> <PLAN_URI> [--description <DESCRIPTION>]
-        Create an assembly from a registered plan.
-
-    solum assembly logs <NAME|UUID>
-        Print an index of all operation logs for an assembly.
-
-    solum assembly delete <NAME|UUID>
-        Destroy an assembly.
-    """
-
-    def create(self):
-        """Create an assembly."""
-        self.parser.add_argument('name',
-                                 type=ValidName,
-                                 help="Assembly name")
-        self.parser.add_argument('plan_uri',
-                                 help="Tenant/project-wide unique "
-                                 "plan (uri/uuid or name)")
-        self.parser.add_argument('--description',
-                                 help="Assembly description")
-        self.parser._names['plan_uri'] = 'plan URI'
-        args = self.parser.parse_args()
-        name = args.name
-        plan_uri = args.plan_uri
-        if '/' not in plan_uri:
-            # might be a plan uuid/name
-            # let's try and be helpful and get the real plan_uri.
-            plan = self.client.plans.find(name_or_id=args.plan_uri)
-            plan_uri = plan.uri
-            print('Note: using plan_uri=%s' % plan_uri)
-
-        assembly = self.client.assemblies.create(name=name,
-                                                 description=args.description,
-                                                 plan_uri=plan_uri)
-        fields = ['uuid', 'name', 'description', 'status', 'application_uri',
-                  'trigger_uri']
-        self._print_dict(assembly, fields, wrap=72)
-
-    def delete(self):
-        """Delete an assembly."""
-        self.parser.add_argument('assembly_uuid',
-                                 help="Assembly uuid or name")
-        self.parser._names['assembly_uuid'] = 'assembly'
-        args = self.parser.parse_args()
-        assem = self.client.assemblies.find(name_or_id=args.assembly_uuid)
-        cli_assem.AssemblyManager(self.client).delete(
-            assembly_id=str(assem.uuid))
-
-    def list(self):
-        """List all assemblies."""
-        fields = ['uuid', 'name', 'description', 'status', 'created_at',
-                  'updated_at']
-        assemblies = self.client.assemblies.list()
-        self._print_list(assemblies, fields, sortby_index=5)
-
-    def logs(self):
-        """Get Logs."""
-        print("Not Supported: Logs moved to workflows. Use  following command."
-              "\nsolum workflow logs app_id wf_id")
-
-    def show(self):
-        """Show an assembly's resource."""
-        self.parser.add_argument('assembly_uuid',
-                                 help="Assembly uuid or name")
-        self.parser._names['assembly_uuid'] = 'assembly'
-        args = self.parser.parse_args()
-        assemblies = self.client.assemblies.find(name_or_id=args.assembly_uuid)
-        fields = ['uuid', 'name', 'description', 'status', 'application_uri',
-                  'created_at', 'updated_at', 'workflow']
-        self._print_dict(assemblies, fields, wrap=72)
-
-
 class ComponentCommands(cli_utils.CommandsBase):
     """Commands for working with components.
 
@@ -407,8 +319,7 @@ Available commands:
         self.parser._names['pipeline_uuid'] = 'pipeline'
         args = self.parser.parse_args()
         pipeline = self.client.pipelines.find(name_or_id=args.pipeline_uuid)
-        cli_pipe.PipelineManager(self.client).delete(
-            pipeline_id=str(pipeline.uuid))
+        self.client.pipelines.delete(pipeline_id=str(pipeline.uuid))
 
     def list(self):
         """List all pipelines."""
@@ -433,8 +344,11 @@ class LanguagePackCommands(cli_utils.CommandsBase):
 
 Available commands:
 
-    solum lp create <NAME> <GIT_REPO_URL>
+    solum lp create <NAME> <GIT_REPO_URL> [--param-file <param-file-name>]
         Create a new language pack from a git repo.
+        You can pass an optional parameter file containing a dictionary.
+        One use of the parameter file is to pass in credentials for
+        infrastructure that should be used to build the lp.
 
     solum lp list
         Print and index of all available language packs.
@@ -451,6 +365,9 @@ Available commands:
 
     def create(self):
         """Create a language pack."""
+        self.parser.add_argument('--param-file',
+                                 dest='paramfile',
+                                 help="Local parameter file location")
         self.parser.add_argument('name',
                                  type=ValidLPName,
                                  help="Language pack name.")
@@ -469,6 +386,15 @@ Available commands:
                                  help="Language pack metadata file.")
         self.parser._names['git_url'] = 'repo URL'
         args = self.parser.parse_args()
+
+        param_data = {}
+        if args.paramfile is not None:
+            try:
+                with open(args.paramfile, 'r') as inf:
+                    param_data = yamlutils.load(inf.read())
+            except Exception as exp:
+                raise exc.CommandException(str(exp))
+
         lp_metadata = None
 
         if args.lp_metadata:
@@ -478,11 +404,13 @@ Available commands:
                 except ValueError as excp:
                     message = ("Malformed metadata file: %s" % str(excp))
                     raise exc.CommandError(message=message)
+
         languagepack = {}
         try:
             languagepack = self.client.languagepacks.create(
                 name=args.name, source_uri=args.git_url,
-                lp_metadata=lp_metadata)
+                lp_metadata=lp_metadata,
+                lp_params=param_data)
         except exceptions.Conflict as conflict:
             message = ("%s" % conflict.message)
             raise exc.CommandError(message=message)
@@ -515,12 +443,11 @@ Available commands:
         self._print_dict(languagepack, fields, wrap=72)
 
     def logs(self):
-        """Get Logs."""
+        """Get language pack Logs."""
         self.parser.add_argument('lp_id',
                                  help="languagepack uuid or name")
         args = self.parser.parse_args()
-        loglist = cli_lp.LanguagePackManager(self.client).logs(
-            lp_id=str(args.lp_id))
+        loglist = self.client.languagepacks.logs(lp_id=str(args.lp_id))
 
         fields = ["resource_uuid", "created_at"]
         for log in loglist:
@@ -557,6 +484,9 @@ Available commands:
                      [--lp <LANGUAGEPACK>]
                      [--param-file <PARAMFILE>]
                      [--setup-trigger]
+                     [--port <PORT>]
+                     [--private-repo]
+                     [--no-languagepack]
                      [--trigger-workflow <CUSTOM-WORKFLOW>]
                       <CUSTOM-WORKFLOW>=(unittest | build | unittest+build)
                       Without the --trigger-workflow flag,
@@ -582,6 +512,7 @@ Available commands:
         the existing workflows. If provided, the logs only for that workflow
         are displayed.
     """
+
     def _validate_app_file(self, app_data):
         if ('workflow_config' in app_data and
                 app_data.get('workflow_config') is None):
@@ -592,8 +523,9 @@ Available commands:
                 msg = "Trigger actions cannot be empty"
                 raise exc.CommandException(message=msg)
 
-        error_message = ("Application name must be 1-100 characters and must "
-                         "only contain a-z,A-Z,0-9,-,_")
+        error_message = ("Application name must be 1-100 characters long, "
+                         "only contain a-z,0-9,-,_ and start with an alphabet "
+                         "character.")
 
         if app_data.get('name') is not None:
             if not name_is_valid(app_data.get('name')):
@@ -604,23 +536,23 @@ Available commands:
 
     def _get_and_validate_app_name(self, app_data, args):
         # Check the appfile-supplied name first.
-        error_message = ("Application name must be 1-100 characters and must "
-                         "only contain a-z,A-Z,0-9,-,_")
+        error_message = ("Application name must be 1-100 characters long, "
+                         "only contain a-z,0-9,-,_ and start with an alphabet "
+                         "character.")
         app_name = ''
-        if app_data.get('name') is not None:
-            if not name_is_valid(app_data.get('name')):
-                raise exc.CommandError(message=error_message)
-            app_name = app_data.get('name')
-        # Check the arguments next.
-        elif args.name:
+        if args.name:
             app_name = args.name
-        # Just ask.
-        else:
+        elif app_data.get('name') is None:
             while True:
-                app_name = raw_input("Please name the application.\n> ")
+                app_name = six.moves.input("Please name the application.\n> ")
                 if name_is_valid(app_name):
                     break
                 print(error_message)
+        else:
+            app_name = app_data.get('name')
+
+        if not name_is_valid(app_name):
+            raise exc.CommandError(message=error_message)
 
         return app_name
 
@@ -629,6 +561,10 @@ Available commands:
         # If it's neither of those places, prompt for it and update the
         # app data.
 
+        if args.no_languagepack:
+            app_data['languagepack'] = "False"
+            return
+
         languagepack = None
         if args.languagepack is not None:
             languagepack = args.languagepack
@@ -655,17 +591,27 @@ Available commands:
                 fields = ['uuid', 'name', 'description',
                           'status', 'source_uri']
                 self._print_list(filtered_list, fields)
-                languagepack = raw_input("Please choose a languagepack from "
-                                         "the above list.\n> ")
+                languagepack = six.moves.input("Please choose a languagepack "
+                                               "from the above list.\n> ")
                 while languagepack not in lpnames + lp_uuids:
-                    languagepack = raw_input("You must choose one of the named"
-                                             " language packs.\n> ")
+                    languagepack = six.moves.input("You must choose one of "
+                                                   "the named  language "
+                                                   "packs.\n> ")
                 app_data['languagepack'] = languagepack
             else:
                 raise exc.CommandError("No languagepack in READY state. "
                                        "Create a languagepack first.")
 
     def _get_app_repo_details(self, app_data, args):
+        def read_private_sshkey(sshkey_file):
+            private_sshkey = ''
+            try:
+                with open(sshkey_file, 'r') as inf:
+                    private_sshkey = inf.read()
+            except Exception as exp:
+                raise exc.CommandException(str(exp))
+            return private_sshkey
+
         git_rev = 'master'
         git_url = None
         if (app_data.get('source') is not None and
@@ -678,10 +624,10 @@ Available commands:
         elif (app_data.get('source') is None or
                 app_data['source'].get('repository') is None or
                 app_data['source']['repository'] is ''):
-            git_url = raw_input("Please specify a git repository URL for "
-                                "your application.\n> ")
-            git_rev_i = raw_input("Please specify revision"
-                                  " (default is master).\n> ")
+            git_url = six.moves.input("Please specify a git repository URL "
+                                      "for your application.\n> ")
+            git_rev_i = six.moves.input("Please specify revision"
+                                        "(default is master).\n> ")
             if git_rev_i is '':
                 git_rev = 'master'
             else:
@@ -690,8 +636,27 @@ Available commands:
         assert(git_url is not None)
         assert(git_rev is not None)
 
+        # check if given repo is a private repository
+        is_private = (args.private_repo or
+                      app_data['source'].get('private', False))
+
+        git_url = transform_git_url(git_url, is_private)
+
+        private_sshkey = app_data['source'].get('private_ssh_key', '')
+        if is_private and not private_sshkey:
+            sshkey_file = six.moves.input("Please specify private sshkey file "
+                                          "full path: ")
+            sshkey_file = sshkey_file.strip()
+            private_sshkey = read_private_sshkey(sshkey_file)
+
+        if is_private and private_sshkey == '':
+            msg = "Must provide private sshkey for private repositories."
+            raise exc.CommandError(message=msg)
+
         git_src = dict()
-        git_src['repository'] = transform_git_url(git_url, False)
+        git_src['private'] = is_private
+        git_src['private_ssh_key'] = private_sshkey
+        git_src['repository'] = git_url
         git_src['revision'] = git_rev
         app_data['source'] = git_src
 
@@ -703,8 +668,8 @@ Available commands:
         elif (app_data.get('workflow_config') is None or
                 app_data['workflow_config'].get('run_cmd') is '' or
                 app_data['workflow_config'].get('run_cmd') is None):
-            run_cmd = raw_input("Please specify start/run command for your "
-                                "application.\n> ")
+            run_cmd = six.moves.input("Please specify start/run command for "
+                                      "your application.\n> ")
 
         if app_data.get('workflow_config') is None:
             run_cmd_dict = dict()
@@ -757,9 +722,10 @@ Available commands:
 
     def _setup_github_trigger(self, app_data, app, args):
         # If a token is supplied, we won't need to generate one.
-        repo_token = ''
-        if hasattr(app_data, 'repo_token'):
-            repo_token = app_data['repo_token']
+        provided_token = ''
+        obtained_token = ''
+        if 'repo_token' in app_data:
+            provided_token = app_data['repo_token']
 
         if args.setup_trigger or args.workflow:
             trigger_uri = vars(app).get('trigger_uri', '')
@@ -769,12 +735,32 @@ Available commands:
                     workflow = args.workflow.replace('+', ' ').split(' ')
                 try:
                     git_url = app_data['source']['repository']
-                    gha = github.GitHubAuth(git_url, repo_token=repo_token)
+
+                    gha = github.GitHubAuth(git_url,
+                                            repo_token=provided_token)
                     gha.create_webhook(trigger_uri, workflow=workflow)
+
+                    if not provided_token:
+                        try:
+                            obtained_token = gha.create_repo_token()
+                            # Update the app with the generated repo_token
+                            to_update = {}
+                            to_update['repo_token'] = obtained_token
+                            self.client.apps.patch(app_id=app.id, **to_update)
+                        except Exception:
+                            print("Error in obtaining github token.")
+                            return ''
+
                 except github.GitHubException as ghe:
                     raise exc.CommandError(message=str(ghe))
 
     def create(self):
+
+        parsed, _ = self.parser.parse_known_args()
+        config.username = parsed.os_username
+        config.password = parsed.os_password
+        config.tenant = parsed.os_tenant_name
+
         self.register()
 
     def register(self):
@@ -783,6 +769,7 @@ Available commands:
                                  dest='appfile',
                                  help="Local appfile location")
         self.parser.add_argument('--name',
+                                 dest='name',
                                  type=ValidName,
                                  help="Application name")
         self.parser.add_argument('--languagepack',
@@ -812,6 +799,15 @@ Available commands:
                                  action='store_true',
                                  dest='setup_trigger',
                                  help="Set up app trigger on git repo")
+        self.parser.add_argument('--no-languagepack',
+                                 action='store_true',
+                                 dest='no_languagepack',
+                                 help="Flag to register an app without"
+                                      " a languagepack")
+        self.parser.add_argument('--private-repo',
+                                 action='store_true',
+                                 dest='private_repo',
+                                 help="Source repo requires authentication.")
 
         trigger_help = ("Which of stages build, unittest, deploy to trigger "
                         "from git. For example: "
@@ -839,6 +835,7 @@ Available commands:
                     'repository': '',
                     'revision': 'master',
                     'private': False,
+                    'private_ssh_key': '',
                     'repo_token': ''
                 },
                 'workflow_config': {
@@ -865,6 +862,10 @@ Available commands:
 
         self._validate_app_data(app_data)
 
+        if args.workflow:
+            app_data['trigger_actions'] = (
+                args.workflow.replace('+', ' ').split(' '))
+
         app = self.client.apps.create(**app_data)
 
         self._setup_github_trigger(app_data, app, args)
@@ -909,6 +910,9 @@ Available commands:
                         },
                         "repo_token": {
                             "type": "string"
+                        },
+                        "private_ssh_key": {
+                            "type": "string"
                         }
                     }
                 },
@@ -1026,21 +1030,20 @@ Available commands:
         args = self.parser.parse_args()
         app = self.client.apps.find(name_or_id=args.name)
 
-        fields = ['name', 'id', 'created_at', 'description', 'languagepack',
-                  'entry_points', 'ports', 'source',
+        fields = ['name', 'id', 'created_at', 'updated_at', 'description',
+                  'languagepack', 'entry_points', 'ports', 'source',
                   'trigger_uuid', 'trigger', 'app_url']
 
         app.trigger = app.trigger_actions
         app.workflow = app.workflow_config
         if app.scale_config:
-            if app.scale_config[args.name]['target']:
-                app.target_instances = app.scale_config[args.name]['target']
+            if app.scale_config[app.name]['target']:
+                app.target_instances = app.scale_config[app.name]['target']
                 fields.append('target_instances')
 
         self._print_dict(app, fields, wrap=72)
 
-        wfman = cli_wf.WorkflowManager(self.client, app_id=app.id)
-        wfs = wfman.list()
+        wfs = self.client.workflows.list(app_id=app.id)
         fields = ['wf_id', 'id', 'status']
         print("'%s' workflows and their status:" % args.name)
         self._print_list(wfs, fields)
@@ -1050,14 +1053,13 @@ Available commands:
         self.parser.add_argument('name')
         args = self.parser.parse_args()
         app = self.client.apps.find(name_or_id=args.name)
-        cli_app.AppManager(self.client).delete(
-            app_id=str(app.id))
+        self.client.apps.delete(app_id=str(app.id))
 
     def _create_scaling_workflow(self, actions, app_name_id, tgt):
         app = self.client.apps.find(name_or_id=app_name_id)
-        wf = (cli_wf.WorkflowManager(self.client,
-                                     app_id=app.id).create(actions=actions,
-                                                           scale_target=tgt))
+        kwargs = {'app_id': app.id, 'actions': actions,
+                  'scale_target': tgt}
+        wf = self.client.workflows.create(**kwargs)
         fields = ['wf_id', 'app_id', 'actions', 'config',
                   'source', 'id', 'created_at', 'updated_at']
         self._print_dict(wf, fields, wrap=72)
@@ -1069,17 +1071,17 @@ Available commands:
             self.parser.add_argument('name')
             args = self.parser.parse_args()
             app = self.client.apps.find(name_or_id=args.name)
-        wf = (cli_wf.WorkflowManager(self.client,
-                                     app_id=app.id).create(actions=actions))
+        kwargs = {'app_id': app.id, 'actions': actions}
+        wf = self.client.workflows.create(**kwargs)
         fields = ['wf_id', 'app_id', 'actions', 'config',
                   'source', 'id', 'created_at', 'updated_at']
         self._print_dict(wf, fields, wrap=72)
 
     def _create_workflow_for_prebuilt_du(self, actions, app_name_id, du_id):
         app = self.client.apps.find(name_or_id=app_name_id)
-        wf = (cli_wf.WorkflowManager(self.client,
-                                     app_id=app.id).create(actions=actions,
-                                                           du_id=du_id))
+        kwargs = {'app_id': app.id, 'actions': actions,
+                  'du_id': du_id}
+        wf = self.client.workflows.create(**kwargs)
         fields = ['wf_id', 'app_id', 'actions', 'config',
                   'source', 'id', 'created_at', 'updated_at']
         self._print_dict(wf, fields, wrap=72)
@@ -1130,14 +1132,14 @@ Available commands:
         self._create_scaling_workflow(actions, args.name, target)
 
     def _display_logs_for_all_workflows(self, app):
-        wfman = cli_wf.WorkflowManager(self.client, app_id=app.id)
-        wfs = wfman.list()
+        wfs = self.client.workflows.list(app_id=app.id)
 
         all_logs_list = []
         fields = ["resource_uuid", "created_at"]
         for wf in wfs:
             revision = wf.wf_id
-            loglist = wfman.logs(revision_or_id=revision)
+            kwargs = {'app_id': app.id, 'revision_or_id': revision}
+            loglist = self.client.workflows.logs(**kwargs)
             for log in loglist:
                 all_logs_list.append(log)
                 strategy_info = json.loads(log.strategy_info)
@@ -1179,10 +1181,10 @@ Available commands:
             self._display_logs_for_all_workflows(app)
 
 
-def display_logs_for_single_workflow(ref, app, revision):
-    wfman = cli_wf.WorkflowManager(ref.client, app_id=app.id)
-    loglist = wfman.logs(revision_or_id=revision)
-    fields = ["resource_uuid"]
+def display_logs_for_single_workflow(self, app, revision):
+    kwargs = {'app_id': app.id, 'revision_or_id': revision}
+    loglist = self.client.workflows.logs(**kwargs)
+    fields = ["resource_uuid", "created_at"]
     for log in loglist:
         strategy_info = json.loads(log.strategy_info)
         if log.strategy == 'local':
@@ -1200,7 +1202,7 @@ def display_logs_for_single_workflow(ref, app, revision):
             if 'location' not in fields:
                 fields.append('location')
 
-    ref._print_list(loglist, fields)
+    self._print_list(loglist, fields)
 
 
 class WorkflowCommands(cli_utils.CommandsBase):
@@ -1223,8 +1225,8 @@ Available commands:
         self.parser.add_argument('app')
         args = self.parser.parse_args()
         app = self.client.apps.find(name_or_id=args.app)
-        wfs = cli_wf.WorkflowManager(self.client, app_id=app.id).list()
-        fields = ['wf_id', 'id', 'actions', 'status',
+        wfs = self.client.workflows.list(app_id=app.id)
+        fields = ['wf_id', 'id', 'actiONs', 'status',
                   'created_at', 'updated_at']
         self._print_list(wfs, fields)
 
@@ -1242,14 +1244,15 @@ Available commands:
             revision = args.workflow
         app = self.client.apps.find(name_or_id=args.app)
 
-        wfman = cli_wf.WorkflowManager(self.client, app_id=app.id)
-        wf = wfman.find(revision_or_id=revision)
+        kwargs = {'app_id': app.id, 'revision_or_id': revision}
+        wf = self.client.workflows.find(**kwargs)
+
         fields = ['wf_id', 'app_id', 'actions', 'config',
                   'source', 'id', 'created_at', 'updated_at', 'status']
         self._print_dict(wf, fields, wrap=72)
 
     def logs(self):
-        """Get Logs."""
+        """Show one of an app's live workflows logs."""
         self.parser.add_argument('app',
                                  help="App uuid or name")
         self.parser.add_argument('workflow',
@@ -1307,8 +1310,9 @@ Available commands:
         elif 'content' not in plan_definition['artifacts'][0]:
             raise exc.CommandException(message="Artifact content missing")
 
-        error_message = ("Application name must be 1-100 characters and must "
-                         "only contain a-z,A-Z,0-9,-,_")
+        error_message = ("Application name must be 1-100 characters long, "
+                         "only contain a-z,0-9,-,_ and start with an alphabet "
+                         "character.")
 
         if plan_definition.get('name') is not None:
             if not name_is_valid(plan_definition.get('name')):
@@ -1323,43 +1327,6 @@ Available commands:
         plans = self.client.plans.list()
         self._print_list(plans, fields)
 
-    def logs(self):
-        """Print a list of all logs belonging to a single app."""
-        self.parser.add_argument('app',
-                                 help="Application name")
-        self.parser._names['app'] = 'application'
-        args = self.parser.parse_args()
-        assemblies = self.client.assemblies.list()
-
-        all_logs_list = []
-        fields = ["resource_uuid", "created_at"]
-        for a in assemblies:
-            plan_uuid = a.plan_uri.split('/')[-1]
-            if args.app not in [plan_uuid, a.name]:
-                continue
-            loglist = cli_assem.AssemblyManager(self.client).logs(
-                assembly_id=str(a.uuid))
-
-            for log in loglist:
-                all_logs_list.append(log)
-                strategy_info = json.loads(log.strategy_info)
-                if log.strategy == 'local':
-                    if 'local_storage' not in fields:
-                        fields.append('local_storage')
-                    log.local_storage = log.location
-                elif log.strategy == 'swift':
-                    if 'swift_container' not in fields:
-                        fields.append('swift_container')
-                    if 'swift_path' not in fields:
-                        fields.append('swift_path')
-                    log.swift_container = strategy_info['container']
-                    log.swift_path = log.location
-                else:
-                    if 'location' not in fields:
-                        fields.append('location')
-
-        self._print_list(all_logs_list, fields)
-
     def show(self):
         """Print detailed information about one application."""
         # This is just "plan show <PLAN>".
@@ -1501,8 +1468,9 @@ Available commands:
         # NOTE: This assumes the plan contains exactly one artifact.
 
         # Check the planfile-supplied name first.
-        error_message = ("Application name must be 1-100 characters and must "
-                         "only contain a-z,A-Z,0-9,-,_")
+        error_message = ("Application name must be 1-100 characters long, "
+                         "only contain a-z,0-9,-,_ and start with an alphabet "
+                         "character.")
         app_name = ''
         if plan_definition.get('name') is not None:
             if not name_is_valid(plan_definition.get('name')):
@@ -1515,7 +1483,7 @@ Available commands:
         # Just ask.
         else:
             while True:
-                app_name = raw_input("Please name the application.\n> ")
+                app_name = six.moves.input("Please name the application.\n> ")
                 if name_is_valid(app_name):
                     break
                 print(error_message)
@@ -1540,11 +1508,12 @@ Available commands:
                 fields = ['uuid', 'name', 'description',
                           'status', 'source_uri']
                 self._print_list(filtered_list, fields)
-                languagepack = raw_input("Please choose a languagepack from "
-                                         "the above list.\n> ")
+                languagepack = six.moves.input("Please choose a languagepack "
+                                               "from the above list.\n> ")
                 while languagepack not in lpnames + lp_uuids:
-                    languagepack = raw_input("You must choose one of the named"
-                                             " language packs.\n> ")
+                    languagepack = six.moves.input("You must choose one of "
+                                                   "the named language "
+                                                   "packs.\n> ")
                 plan_definition['artifacts'][0]['language_pack'] = languagepack
             else:
                 raise exc.CommandError("No languagepack in READY state. "
@@ -1558,8 +1527,8 @@ Available commands:
         if args.git_url is not None:
             plan_definition['artifacts'][0]['content']['href'] = args.git_url
         if plan_definition['artifacts'][0]['content'].get('href') is None:
-            git_url = raw_input("Please specify a git repository URL for "
-                                "your application.\n> ")
+            git_url = six.moves.input("Please specify a git repository URL "
+                                      "for your application.\n> ")
             plan_definition['artifacts'][0]['content']['href'] = git_url
         git_url = plan_definition['artifacts'][0]['content']['href']
 
@@ -1591,8 +1560,8 @@ Available commands:
         if args.run_cmd is not None:
             plan_definition['artifacts'][0]['run_cmd'] = args.run_cmd
         if plan_definition['artifacts'][0].get('run_cmd') is None:
-            run_cmd = raw_input("Please specify start/run command for your "
-                                "application.\n> ")
+            run_cmd = six.moves.input("Please specify start/run command for "
+                                      "your application.\n> ")
             plan_definition['artifacts'][0]['run_cmd'] = run_cmd
 
         # Check for unit test command
@@ -1616,8 +1585,7 @@ Available commands:
         if not lpname_is_valid(a_name):
             # https://github.com/docker/compose/issues/941
             # Docker build only allows lowercase names for now.
-            msg = ("Artifact names must be 1-100 characters long and "
-                   "must only contain a-z,0-9,-,_")
+            msg = name_error_message("Artifact names")
             raise exc.CommandError(msg)
         plan_definition['artifacts'][0]['name'] = a_name
 
@@ -1705,7 +1673,7 @@ Available commands:
         except exceptions.NotFound:
             message = "No app named '%s'." % args.app
             raise exceptions.NotFound(message=message)
-        cli_plan.PlanManager(self.client).delete(plan_id=str(plan.uuid))
+        self.client.plans.delete(plan_id=str(plan.uuid))
 
 
 class InfoCommands(cli_utils.NoSubCommands):
@@ -1910,14 +1878,6 @@ Available commands:
                      [--trigger-workflow <WORKFLOW>]
         Register a new application with Solum.
 
-    solum assembly list
-        Print an index of all available assemblies.
-
-    solum assembly create <NAME|UUID> <PLAN_URI> [--description <DESCRIPTION>]
-        Create an assembly from a registered plan.
-
-    solum assembly delete <NAME|UUID>
-        Destroy an assembly.
     """
 
     parser = PermissiveParser()
@@ -1926,7 +1886,6 @@ Available commands:
         'oldapp': OldAppCommands,
         'app': AppCommands,
         'plan': PlanCommands,
-        'assembly': AssemblyCommands,
         'pipeline': PipelineCommands,
         'lp': LanguagePackCommands,
         'languagepack': LanguagePackCommands,
