@@ -16,11 +16,11 @@
 # under the License.
 
 import fixtures
-
-from solumclient.openstack.common import test
+from oslotest import base
+import testscenarios
 
 
-class TestCase(test.BaseTestCase):
+class TestCase(testscenarios.WithScenarios, base.BaseTestCase):
 
     """Test case base class for all unit tests."""
 
